Module bisync

Module bisync 

Available on crate features async-client or blocking-client only.
Attribute macros and mode flags for sharing async-shaped implementations between client modes.

Constants

ASYNC
Whether the async implementation is selected.
SYNC
Whether the blocking implementation is selected.

Attribute Macros

bisyncblocking-client
Turn async-shaped Rust code into its blocking equivalent by removing async and .await tokens.
only_asyncblocking-client
Remove an item when selecting one side of a shared blocking and async implementation.
only_syncblocking-client
Keep an item unchanged when selecting one side of a shared blocking and async implementation.