pub struct LsRefsCommand<'a> { /* private fields */ }Available on crate features
async-client or blocking-client only.Expand description
A command to list references from a remote Git repository.
Its invocation uses the same implementation with either blocking or asynchronous I/O.
Implementations
Sourceimpl<'a> LsRefsCommand<'a>
impl<'a> LsRefsCommand<'a>
Sourcepub fn new(
ref_prefixes: Option<RefPrefixes>,
capabilities: &'a Capabilities,
agent: Feature,
) -> Self
pub fn new( ref_prefixes: Option<RefPrefixes>, capabilities: &'a Capabilities, agent: Feature, ) -> Self
Build a command to list refs from the given server capabilities,
using agent information to identify ourselves.
Use crate::ls_refs::RefPrefixes::from_refspecs() to construct ref_prefixes
from refspecs, or crate::ls_refs::RefPrefixes::new() to build them manually.
Sourcepub fn invoke_blocking(
self,
transport: impl Transport,
progress: &mut impl Progress,
trace: bool,
) -> Result<Vec<Ref>, Error>
pub fn invoke_blocking( self, transport: impl Transport, progress: &mut impl Progress, trace: bool, ) -> Result<Vec<Ref>, Error>
Invoke a ls-refs V2 command on transport.
progress is used to provide feedback.
If trace is true, all packetlines received or sent will be passed to the facilities of the gix-trace crate.