Available on crate features
async-client or blocking-client only.Expand description
Attribute macros and mode flags for sharing async-shaped implementations between client modes.
Constants
- ASYNC
- Whether the async implementation is selected.
- SYNC
- Whether the blocking implementation is selected.
Attribute Macros
- bisync
blocking-client - Turn async-shaped Rust code into its blocking equivalent by removing
asyncand.awaittokens. - only_
async blocking-client - Remove an item when selecting one side of a shared blocking and async implementation.
- only_
sync blocking-client - Keep an item unchanged when selecting one side of a shared blocking and async implementation.